@@ -59,11 +59,11 @@ typedef struct _GnomeCanvasGCP           GnomeCanvasGCP;
 typedef struct _GnomeCanvasGCPClass      GnomeCanvasGCPClass;
 
 #define GNOME_TYPE_CANVAS_GCP            (gnome_canvas_gcp_get_type ())
-#define GNOME_CANVAS_GCP(obj)            (GTK_CHECK_CAST ((obj), GNOME_TYPE_CANVAS_GCP, GnomeCanvasGCP))
-#define GNOME_CANVAS_CLASS_GCP(klass)    (GTK_CHECK_CLASS_CAST ((klass), GNOME_TYPE_CANVAS_GCP, GnomeCanvasGCPClass))
-#define GNOME_IS_CANVAS_GCP(obj)         (GTK_CHECK_TYPE ((obj), GNOME_TYPE_CANVAS_GCP))
-#define GNOME_IS_CANVAS_GCP_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_CANVAS_GCP))
-#define GNOME_CANVAS_GCP_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), GNOME_TYPE_CANVAS_GCP, GnomeCanvasGCPClass))
+#define GNOME_CANVAS_GCP(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_TYPE_CANVAS_GCP, GnomeCanvasGCP))
+#define GNOME_CANVAS_CLASS_GCP(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_TYPE_CANVAS_GCP, GnomeCanvasGCPClass))
+#define GNOME_IS_CANVAS_GCP(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_TYPE_CANVAS_GCP))
+#define GNOME_IS_CANVAS_GCP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_CANVAS_GCP))
+#define GNOME_CANVAS_GCP_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_TYPE_CANVAS_GCP, GnomeCanvasGCPClass))
 
 enum {
   UPDATE_BOUNDS,
@@ -266,7 +266,7 @@ bool View::OnEvent (GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 						pAtom->GetCoords (&xa, &ya, NULL);
 						xa *= pTheme->GetZoomFactor ();
 						ya *= pTheme->GetZoomFactor ();
-						xa =- x;
+						xa -= x;
 						ya -= y;
 						if (sqrt (xa * xa + ya * ya) < 3.5) {
 							//3.5 is arbitrary
@@ -277,13 +277,26 @@ bool View::OnEvent (GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 						pAtom->GetCoords (&xa, &ya, NULL);
 						xa *= pTheme->GetZoomFactor ();
 						ya *= pTheme->GetZoomFactor ();
-						xa =- x;
+						xa -= x;
 						ya -= y;
 						if (sqrt (xa * xa + ya * ya) < 3.5) {
 							m_CurObject = pAtom;
 							break;
 						}
 					}
+				} else if ((*i).first->GetType () == gcu::AtomType) {
+					double xa, ya;
+					gcu::Atom *pAtom = (gcu::Atom*) (*i).first;
+					pAtom->GetCoords (&xa, &ya, NULL);
+					xa *= pTheme->GetZoomFactor ();
+					ya *= pTheme->GetZoomFactor ();
+					xa -= x;
+					ya -= y;
+					if (sqrt (xa * xa + ya * ya) < 3.5) {
+						//3.5 is arbitrary
+						m_CurObject = pAtom;
+						break;
+					}
 				}
 				i++;
 			}
@@ -1199,6 +1212,8 @@ void View::Render (cairo_t *cr)
 		pObj = (Object*) g_object_get_data (G_OBJECT (m_ActiveRichText), "object");
 		if (pObj) pObj->SetSelected (m_pWidget, SelStateUnselected);
 	}
+	GnomeCanvas *canvas = GNOME_CANVAS (m_pWidget);
+	gnome_canvas_update_now (canvas);
 	g_printable_draw_cairo (G_PRINTABLE (m_pData->Group), cr);
 	m_pData->ShowSelection (true);
 	if (pObj)
