@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * filechooser.cc 
  *
- * Copyright (C) 2006-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,9 +26,9 @@
 #include "filechooser.h"
 #include <gcu/application.h>
 #include <gcu/document.h>
-#include <glib/gi18n.h>
+#include <gio/gio.h>
+#include <glib/gi18n-lib.h>
 #include <goffice/utils/go-file.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
 
 using namespace std;
 
@@ -113,8 +113,10 @@ FileChooser::FileChooser (Application *App, bool Save, list<string> mime_types,
 			filename = gtk_file_chooser_get_uri (chooser);
 			if (!mime_type) {
 				mime_type = go_get_mime_type (filename);
+#ifdef GOFFICE_IS_0_6
 				if (!mime_type)
-					mime_type = gnome_vfs_get_file_mime_type_fast (filename, NULL);
+					mime_type = g_content_type_guess (filename, NULL, 0, NULL);
+#endif
 				// ensure the found mime type is in the list
 				bool found = false;
 				if (mime_type) {
